# slvrov-tools

A utility library for SLVROV that includes tools for:

- Non-trivial math operations
- Network communication
- Netowkr setup
- Exit handling
- Joysticks
- I2C control
- PCA9685 utils
- Misc tools
- CLI for gstreamer installation, udp video streaming

## Github
[slrov-tools github](https://github.com/LegionaryOfLogic/slvrov-tools)

## Installation

```bash
pip install slvrov-tools